import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:snake/config/application_config.dart';
import 'package:snake/models/activity/cell.dart';
import 'package:snake/models/activity/cell_location.dart';

typedef BoardCells = List<List<Cell>>;

class Board {
  final BoardCells cells;

  Board({
    required this.cells,
  });

  factory Board.createEmpty(ActivitySettings activitySettings) {
    final int boardSizeHorizontal =
        activitySettings.getAsInt(ApplicationConfig.parameterCodeBoardSize);
    final int boardSizeVertical =
        activitySettings.getAsInt(ApplicationConfig.parameterCodeBoardSize);

    BoardCells cells = [];
    for (int rowIndex = 0; rowIndex < boardSizeVertical; rowIndex++) {
      List<Cell> row = [];
      for (int colIndex = 0; colIndex < boardSizeHorizontal; colIndex++) {
        row.add(Cell(CellValue.empty));
      }
      cells.add(row);
    }

    return Board(
      cells: cells,
    );
  }

  CellValue getCellValue(CellLocation cellLocation) {
    return cells[cellLocation.row][cellLocation.col].value;
  }

  void setCellValue(CellLocation cellLocation, CellValue cellValue) {
    cells[cellLocation.row][cellLocation.col].value = cellValue;
  }

  @override
  String toString() {
    return '$Board(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'cells': cells,
    };
  }
}
