import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:snake/config/application_config.dart';
import 'package:snake/models/activity/cell_location.dart';

typedef SnakeCells = List<CellLocation>;

enum SnakeDirection { top, left, bottom, right }

class Snake {
  // Snake's cells: last in list is head
  SnakeCells cells;
  int size;
  SnakeDirection direction;

  Snake({
    required this.cells,
    required this.size,
    required this.direction,
  });

  factory Snake.create(ActivitySettings activitySettings) {
    // Default init snake size
    const int initialLength = 3;

    // ~ center cell:
    final int middleColumn =
        activitySettings.getAsInt(ApplicationConfig.parameterCodeBoardSize) ~/ 2;
    final int middleRow =
        activitySettings.getAsInt(ApplicationConfig.parameterCodeBoardSize) ~/ 2;

    SnakeCells cells = [
      CellLocation.go(middleRow, middleColumn),
    ];

    return Snake(
      cells: cells,
      size: initialLength,
      direction: SnakeDirection.right,
    );
  }

  CellLocation get head => cells[cells.length - 1];

  @override
  String toString() {
    return '$Snake(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'cells': cells,
      'size': size,
      'direction': direction.toString(),
    };
  }
}
