import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';
import 'package:snake/config/application_config.dart';

import 'package:snake/cubit/activity/activity_cubit.dart';
import 'package:snake/models/activity/cell.dart';
import 'package:snake/models/activity/activity.dart';

class CellWidget extends StatelessWidget {
  const CellWidget({
    super.key,
    required this.cellValue,
  });

  final CellValue cellValue;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ActivityCubit, ActivityState>(
      builder: (BuildContext context, ActivityState activityState) {
        final Activity currentActivity = activityState.currentActivity;

        final String skin =
            currentActivity.activitySettings.get(ApplicationConfig.parameterCodeSkin);
        final String cellValueCode = getCellValueAsset(cellValue);
        final String imageAsset = 'assets/skins/${skin}_$cellValueCode.png';

        return Image(
          image: AssetImage(imageAsset),
          fit: BoxFit.fill,
        );
      },
    );
  }

  String getCellValueAsset(CellValue cellValue) {
    String cellValueAsset = 'empty';

    switch (cellValue) {
      case CellValue.empty:
        cellValueAsset = 'empty';
      case CellValue.head:
        cellValueAsset = 'head';
      case CellValue.body:
        cellValueAsset = 'body';
      case CellValue.fruit:
        cellValueAsset = 'fruit';
    }

    return cellValueAsset;
  }
}
